/*
 * Copyright (c) 2006, David Peterson
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 * 			 notice, this list of conditions and the following disclaimer in the
 *   		 documentation and/or other materials provided with the distribution.
 *     * Neither the name of "randombits.org" nor the names of its contributors
 * 			 may be used to endorse or promote products derived from this software
 * 			 without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.randombits.storage.confluence;

import com.atlassian.confluence.content.render.xhtml.ConversionContext;
import org.randombits.storage.ObjectBasedStorage;

import java.util.Collections;
import java.util.Set;

/**
 * Provides a storage implementation for accessing properties stored in the
 * ConversionContext.
 *
 * @author david@randombits.org
 */
public class ConversionContextStorage extends ObjectBasedStorage {

    private ConversionContext conversionContext;

    public ConversionContextStorage( ConversionContext conversionContext ) {
        super( BoxType.Real );
        this.conversionContext = conversionContext;
    }

    @Override
    protected Set<String> baseNameSet() {
        return Collections.EMPTY_SET;
    }

    @Override
    protected Object getBaseObject( String name ) {
        return conversionContext.getProperty( name );
    }

    @Override
    protected void setBaseObject( String name, Object value ) {
        if ( value != null )
            conversionContext.setProperty( name, value );
        else
            conversionContext.removeProperty( name );
    }

    /**
     * @see org.randombits.storage.Storage#isReadOnly()
     */
    @Override
    public boolean isReadOnly() {
        return false;
    }
}
